@@ -216,6 +216,25 @@ arv_buffer_get_chunk_data (ArvBuffer *buffer, guint64 chunk_id, size_t *size)
 	return NULL;
 }
 
+/**
+ * arv_buffer_get_user_data:
+ * @buffer: a #ArvBuffer
+ *
+ * Gets a pointer to user data set by arv_buffer_new_full.
+ *
+ * Returns: user data, or NULL if not set.
+ *
+ * Since: 0.4.0
+ */
+
+const void *
+arv_buffer_get_user_data (ArvBuffer *buffer)
+{
+	g_return_val_if_fail (ARV_IS_BUFFER (buffer), NULL);
+	
+	return buffer->priv->user_data;
+}
+
 /**
  * arv_buffer_get_status:
  * @buffer: a #ArvBuffer
@@ -279,9 +298,9 @@ arv_buffer_get_payload_type (ArvBuffer *buffer)
  * arv_buffer_get_timestamp:
  * @buffer: a #ArvBuffer
  *
- * Gets the buffer camera timestamp, expressed as nanoseconds. Not all devices provide
- * reliable timestamp, which means sometimes its better to rely on the buffer
- * completion host local time (given by @g_get_realtime for example).
+ * Gets the buffer camera timestamp, expressed as nanoseconds. Not all devices
+ * provide reliable timestamp, which means sometimes its better to rely on the
+ * buffer completion host local time (given by @g_get_realtime for example).
  *
  * Returns: buffer timestamp, in nanoseconds.
  *
@@ -296,6 +315,26 @@ arv_buffer_get_timestamp (ArvBuffer *buffer)
 	return buffer->priv->timestamp_ns;
 }
 
+/**
+ * arv_buffer_get_frame_id:
+ * @buffer: a #ArvBuffer
+ *
+ * Gets the buffer frame id. For GigEVision devices, valid values are in the
+ * 1..65535 range.
+ *
+ * Returns: frame id, 0 on error.
+ *
+ * Since: 0.4.0
+ */
+
+guint32
+arv_buffer_get_frame_id (ArvBuffer *buffer)
+{
+	g_return_val_if_fail (ARV_IS_BUFFER (buffer), 0);
+
+	return buffer->priv->frame_id;
+}
+
 /**
  * arv_buffer_get_image_region:
  * @buffer: a #ArvBuffer
@@ -312,8 +351,8 @@ arv_buffer_get_timestamp (ArvBuffer *buffer)
 void
 arv_buffer_get_image_region (ArvBuffer *buffer, gint *x, gint *y, gint *width, gint *height)
 {
-	g_return_val_if_fail (ARV_IS_BUFFER (buffer), 0);
-	g_return_val_if_fail (buffer->priv->gvsp_payload_type == ARV_GVSP_PAYLOAD_TYPE_IMAGE, 0);
+	g_return_if_fail (ARV_IS_BUFFER (buffer));
+	g_return_if_fail (buffer->priv->gvsp_payload_type == ARV_GVSP_PAYLOAD_TYPE_IMAGE);
 
 	if (x != NULL)
 		*x = buffer->priv->x_offset;
