@@ -48,8 +48,9 @@
 #include <arvgcenumentry.h>
 #include <arvgcstring.h>
 #include <arvgc.h>
-#include <arvdevice.h>
+#include <arvgvdevice.h>
 #include <arvenums.h>
+#include <arvstr.h>
 
 /**
  * ArvCameraVendor:
@@ -556,6 +557,23 @@ arv_camera_stop_acquisition (ArvCamera *camera)
 	arv_device_execute_command (camera->priv->device, "AcquisitionStop");
 }
 
+/**
+ * arv_camera_abort_acquisition:
+ * @camera: a #ArvCamera
+ *
+ * Aborts video stream acquisition.
+ *
+ * Since: 0.4.0
+ */
+
+void
+arv_camera_abort_acquisition (ArvCamera *camera)
+{
+	g_return_if_fail (ARV_IS_CAMERA (camera));
+
+	arv_device_execute_command (camera->priv->device, "AcquisitionAbort");
+}
+
 /*
  * arv_camera_set_acquisition_mode:
  * @camera: a #ArvCamera
@@ -1185,7 +1203,7 @@ arv_camera_get_device (ArvCamera *camera)
  * arv_camera_is_frame_rate_available:
  * @camera: a #ArvCamera
  *
- * Returns: TRUE if FrameRate feature is available
+ * Returns: %TRUE if FrameRate feature is available
  *
  * Since: 0.2.0
  */
@@ -1216,7 +1234,7 @@ arv_camera_is_frame_rate_available (ArvCamera *camera)
  * arv_camera_is_exposure_time_available:
  * @camera: a #ArvCamera
  *
- * Returns: TRUE if Exposure Time feature is available.
+ * Returns: %TRUE if Exposure Time feature is available.
  *
  * Since: 0.2.0
  */
@@ -1236,7 +1254,7 @@ arv_camera_is_exposure_time_available (ArvCamera *camera)
  * arv_camera_is_exposure_auto_available:
  * @camera: a #ArvCamera
  *
- * Returns: TRUE if Exposure Auto feature is available.
+ * Returns: %TRUE if Exposure Auto feature is available.
  *
  * Since: 0.2.0
  */
@@ -1253,7 +1271,7 @@ arv_camera_is_exposure_auto_available (ArvCamera *camera)
  * arv_camera_is_gain_available:
  * @camera: a #ArvCamera
  *
- * Returns: TRUE if Gain feature is available.
+ * Returns: %TRUE if Gain feature is available.
  *
  * Since: 0.2.0
  */
@@ -1273,7 +1291,7 @@ arv_camera_is_gain_available (ArvCamera *camera)
  * arv_camera_is_gain_auto_available:
  * @camera: a #ArvCamera
  *
- * Returns: TRUE if Gain feature is available.
+ * Returns: %TRUE if Gain feature is available.
  *
  * Since: 0.2.0
  */
@@ -1286,6 +1304,177 @@ arv_camera_is_gain_auto_available (ArvCamera *camera)
 	return arv_device_get_feature (camera->priv->device, "GainAuto") != NULL;
 }
 
+/**
+ * arv_camera_is_gv_device:
+ * @camera: a #ArvCamera
+ *
+ * Returns: %TRUE if @camera is a GigEVision device.
+ *
+ * Since: 0.4.0
+ */
+
+gboolean
+arv_camera_is_gv_device	(ArvCamera *camera)
+{
+	g_return_val_if_fail (ARV_IS_CAMERA (camera), FALSE);
+
+	return ARV_IS_GV_DEVICE (camera->priv->device);
+}
+
+/**
+ * arv_camera_gv_get_n_stream_channels:
+ * @camera: a #ArvCamera
+ *
+ * Returns: the number of supported stream channels.
+ *
+ * Since: 0.4.0
+ */
+
+gint
+arv_camera_gv_get_n_stream_channels (ArvCamera *camera)
+{
+	g_return_val_if_fail (arv_camera_is_gv_device (camera), 0);
+
+	return arv_device_get_integer_feature_value (camera->priv->device, "GevStreamChannelCount");
+}
+
+/**
+ * arv_camera_gv_select_stream_channel:
+ * @camera: a #ArvCamera
+ * @channel_id: id of the channel to select
+ *
+ * Select the current stream channel.
+ *
+ * Since: 0.4.0
+ */
+
+void
+arv_camera_gv_select_stream_channel (ArvCamera *camera, gint channel_id)
+{
+	if (channel_id < 0)
+		return;
+
+	g_return_if_fail (arv_camera_is_gv_device (camera));
+
+	arv_device_set_integer_feature_value (camera->priv->device, "GevStreamChannelSelector", channel_id);
+}
+
+/**
+ * arv_camera_gv_get_current_stream_channel:
+ * @camera: a #ArvCamera
+ *
+ * Returns: The current stream channel id.
+ *
+ * Since: 0.4.0
+ */
+
+int
+arv_camera_gv_get_current_stream_channel (ArvCamera *camera)
+{
+	g_return_val_if_fail (arv_camera_is_gv_device (camera), 0);
+
+	return arv_device_get_integer_feature_value (camera->priv->device, "GevStreamChannelSelector");
+}
+
+/**
+ * arv_camera_gv_set_packet_delay:
+ * @camera: a #ArvCamera
+ * @delay_ns: inter packet delay, in nanoseconds
+ *
+ * Configure the inter packet delay to insert between each packet for the current stream
+ * channel. This can be used as a crude flow-control mechanism if the application or the network
+ * infrastructure cannot keep up with the packets coming from the device.
+ *
+ * Since: 0.4.0
+ */
+
+void
+arv_camera_gv_set_packet_delay (ArvCamera *camera, gint64 delay_ns)
+{
+	gint64 tick_frequency;
+	gint64 value;
+
+	if (delay_ns < 0)
+		return;
+
+	g_return_if_fail (arv_camera_is_gv_device (camera));
+
+	tick_frequency = arv_device_get_integer_feature_value (camera->priv->device, "GevTimestampTickFrequency");
+	if (tick_frequency <= 0)
+		return;
+
+	value = tick_frequency * delay_ns / 1000000000LL;
+	arv_device_set_integer_feature_value (camera->priv->device, "GevSCPD", value);
+}
+
+/**
+ * arv_camera_gv_get_packet_delay:
+ * @camera: a #ArvCamera
+ *
+ * Returns: The inter packet delay, in nanoseconds.
+ *
+ * Since: 0.4.0
+ */
+
+gint64
+arv_camera_gv_get_packet_delay (ArvCamera *camera)
+{
+	gint64 tick_frequency;
+	gint64 value;
+
+	g_return_val_if_fail (arv_camera_is_gv_device (camera), 0);
+
+	tick_frequency = arv_device_get_integer_feature_value (camera->priv->device, "GevTimestampTickFrequency");
+	if (tick_frequency <= 0)
+		return 0;
+
+	value = arv_device_get_integer_feature_value (camera->priv->device, "GevSCPD");
+
+	return value * 1000000000LL / tick_frequency;
+}
+
+/**
+ * arv_camera_gv_set_packet_size:
+ * @camera: a #ArvCamera
+ * @packet_size: packet size, in bytes
+ *
+ * Specifies the stream packet size, in bytes, to send on the selected channel for a GVSP transmitter
+ * or specifies the maximum packet size supported by a GVSP receiver.
+ *
+ * This does not include data leader and data trailer and the last data packet which might be of
+ * smaller size (since packet size is not necessarily a multiple of block size for stream channel).
+ *
+ * Since: 0.4.0
+ */
+
+void
+arv_camera_gv_set_packet_size (ArvCamera *camera, gint packet_size)
+{
+	if (packet_size <= 0)
+		return;
+
+	g_return_if_fail (arv_camera_is_gv_device (camera));
+
+	arv_device_set_integer_feature_value (camera->priv->device, "GevSCPSPacketSize", packet_size);
+}
+
+/**
+ * arv_camera_gv_get_packet_size:
+ * @camera: a #ArvCamera
+ *
+ * Returns: The stream packet size, in bytes.
+ *
+ * Since: 0.4.0
+ */
+
+gint
+arv_camera_gv_get_packet_size (ArvCamera *camera)
+{
+	g_return_val_if_fail (arv_camera_is_gv_device (camera), 0);
+
+	return arv_device_get_integer_feature_value (camera->priv->device, "GevSCPSPacketSize");
+}
+
 /**
  * arv_camera_set_chunk_mode:
  * @camera: a #ArvCamera
@@ -1310,7 +1499,7 @@ arv_camera_set_chunk_mode (ArvCamera *camera, gboolean is_active)
  * arv_camera_get_chunk_mode:
  * @camera: a #ArvCamera
  *
- * Check wether chunk data mode is active. Please see @arv_camera_set_chunk_mode.
+ * Check wether chunk data mode is active. Please see arv_camera_set_chunk_mode().
  *
  * Returns: %TRUE if chunk data mode is active.
  *
@@ -1332,7 +1521,7 @@ arv_camera_get_chunk_mode (ArvCamera *camera)
  * @is_enabled: wether to enable this chunk
  *
  * Sets state of a chunk data. Chunk data are be embedded in #ArvBuffer only
- * if chunk mode is active. Please see @arv_camera_set_chunk_mode.
+ * if chunk mode is active. Please see arv_camera_set_chunk_mode().
  *
  * Since: 0.4.0
  **/
@@ -1353,7 +1542,7 @@ arv_camera_set_chunk_state (ArvCamera *camera, const char *chunk, gboolean is_en
  * @chunk: chunk data name
  *
  * Gets state of chunk data. Chunk data are be embedded in #ArvBuffer only
- * if chunk mode is active. Please see @arv_camera_set_chunk_mode.
+ * if chunk mode is active. Please see arv_camera_set_chunk_mode().
  *
  * Returns: %TRUE if @chunk is enabled.
  *
@@ -1385,6 +1574,7 @@ void
 arv_camera_set_chunks (ArvCamera *camera, const char *chunk_list)
 {
 	char **chunks;
+	char *striped_chunk_list;
 	gboolean enable_chunk_data = FALSE;
 	int i;
 	guint n_values;
@@ -1398,10 +1588,14 @@ arv_camera_set_chunks (ArvCamera *camera, const char *chunk_list)
 
 	chunks = (char **) arv_device_get_available_enumeration_feature_values_as_strings (camera->priv->device,
 											   "ChunkSelector", &n_values);
-	for (i = 0; i < n_values; i++)
+	for (i = 0; i < n_values; i++) {
 		arv_camera_set_chunk_state (camera, chunks[i], FALSE);
+	}
 
-	chunks = g_strsplit_set (chunk_list, " ,:;", -1);
+	striped_chunk_list = g_strdup (chunk_list);
+	arv_str_strip (striped_chunk_list, " ,:;", ',');
+	chunks = g_strsplit_set (striped_chunk_list, " ,:;", -1);
+	g_free (striped_chunk_list);
 
 	for (i = 0; chunks[i] != NULL; i++) {
 		arv_camera_set_chunk_state (camera, chunks[i], TRUE);
@@ -1537,7 +1731,8 @@ arv_camera_constructor (GType gtype, guint n_properties, GObjectConstructParam *
 
 	camera->priv->use_gain_raw = !ARV_IS_GC_FLOAT (arv_device_get_feature (camera->priv->device, "Gain"));
 	camera->priv->use_exposure_time_abs = !ARV_IS_GC_FLOAT (arv_device_get_feature (camera->priv->device, "ExposureTime"));
-	camera->priv->use_acquisition_frame_rate_abs = !ARV_IS_GC_FLOAT (arv_device_get_feature (camera->priv->device, "AcquisitionFrameRate"));
+	camera->priv->use_acquisition_frame_rate_abs = !ARV_IS_GC_FLOAT (arv_device_get_feature (camera->priv->device,
+												 "AcquisitionFrameRate"));
 
     return object;
 }
