@@ -83,6 +83,7 @@ const char **	arv_camera_get_available_pixel_formats_as_display_names	(ArvCamera
 
 void		arv_camera_start_acquisition		(ArvCamera *camera);
 void		arv_camera_stop_acquisition		(ArvCamera *camera);
+void		arv_camera_abort_acquisition		(ArvCamera *camera);
 
 void			arv_camera_set_acquisition_mode 	(ArvCamera *camera, ArvAcquisitionMode value);
 ArvAcquisitionMode 	arv_camera_get_acquisition_mode 	(ArvCamera *camera);
@@ -122,6 +123,19 @@ ArvAuto		arv_camera_get_gain_auto	(ArvCamera *camera);
 
 guint		arv_camera_get_payload		(ArvCamera *camera);
 
+/* GigEVision specific API */
+
+gboolean	arv_camera_is_gv_device			(ArvCamera *camera);
+
+gint		arv_camera_gv_get_n_stream_channels	(ArvCamera *camera);
+void		arv_camera_gv_select_stream_channel	(ArvCamera *camera, gint channel_id);
+int 		arv_camera_gv_get_current_stream_channel(ArvCamera *camera);
+
+void		arv_camera_gv_set_packet_delay		(ArvCamera *camera, gint64 delay_ns);
+gint64 		arv_camera_gv_get_packet_delay 		(ArvCamera *camera);
+void 		arv_camera_gv_set_packet_size 		(ArvCamera *camera, gint packet_size);
+gint		arv_camera_gv_get_packet_size		(ArvCamera *camera);
+
 /* Chunk data */
 
 void 			arv_camera_set_chunk_mode 	(ArvCamera *camera, gboolean is_active);
