@@ -605,6 +605,9 @@ arv_chunk_parser_status_get_type (void)
 			{ ARV_CHUNK_PARSER_STATUS_CHUNK_NOT_FOUND,
 			  "ARV_CHUNK_PARSER_STATUS_CHUNK_NOT_FOUND",
 			  "chunk-not-found" },
+			{ ARV_CHUNK_PARSER_STATUS_INVALID_FEATURE_NAME,
+			  "ARV_CHUNK_PARSER_STATUS_INVALID_FEATURE_NAME",
+			  "invalid-feature-name" },
 			{ 0, NULL, NULL }
 		};
 		the_type = g_enum_register_static (
